@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.2.15';
+our $VERSION = '0.2.16';
 
 1;
 
@@ -1382,6 +1382,17 @@ Run in silent mode. By default strun prints all scenarios output, to disable thi
 
 =item *
 
+C<--purge-cache>
+
+
+=back
+
+Purge strun cache upon exit. By default C<--purge-cache> is disabled ( cache remains to allow debugging and troubleshooting ).
+
+=over
+
+=item *
+
 C<--match_l> 
 
 
